Crate erebus

Crate erebus 

Structs

Characters
ColorGenerator
A type that can generate distinct 8-bit colors.
Label
Message
NoFile
Note
Style

Enums

Color
Enum representing a terminal color.
Identifier
Severity

Traits

FileId
Files
A trait for types that can provide information about files.
Render

Functions

break_line
Breaks text into a series of lines, each of which is no longer than width characters.
Breaks text in-between words, if possible.